package usecase

import (
	"app-cloudep-notification-service/internal/config"
	"app-cloudep-notification-service/internal/domain/usecase"
	"context"
	"gopkg.in/gomail.v2"
)

type MailUseCaseParam struct {
	Conf config.Config
}

type MailUseCase struct {
	Host     string
	Port     int
	User     string
	Password string
}

func (mu *MailUseCase) SendMail(_ context.Context, req usecase.MailReq) error {
	m := gomail.NewMessage()
	m.SetHeader("From", req.From)
	m.SetHeader("To", req.To)
	m.SetHeader("Subject", req.Subject)
	m.SetBody("text/html", req.Body)
	d := gomail.NewDialer(mu.Host, mu.Port, mu.User, mu.Password)
	if err := d.DialAndSend(m); err != nil {
		return err
	}
	return nil
}

func MustMailgunUseCase(param MailUseCaseParam) usecase.MailClientUseCase {
	return &MailUseCase{
		Host:     param.Conf.SMTP.Host,
		Port:     param.Conf.SMTP.Port,
		User:     param.Conf.SMTP.User,
		Password: param.Conf.SMTP.Password,
	}
}
